import { Model, setValidateFunc, createTypeMetaGuard } from "@kubernetes-models/base";
import { validate } from "../../_schemas/GatewayNetworkingK8sIoV1alpha2ReferenceGrant.mjs";
/**
 * ReferenceGrant identifies kinds of resources in other namespaces that are trusted to reference the specified kinds of resources in the same namespace as the policy.
 *  Each ReferenceGrant can be used to represent a unique trust relationship. Additional Reference Grants can be used to add to the set of trusted sources of inbound references for the namespace they are defined within.
 *  A ReferenceGrant is required for all cross-namespace references in Gateway API (with the exception of cross-namespace Route-Gateway attachment, which is governed by the AllowedRoutes configuration on the Gateway, and cross-namespace Service ParentRefs on a "consumer" mesh Route, which defines routing rules applicable only to workloads in the Route namespace). ReferenceGrants allowing a reference from a Route to a Service are only applicable to BackendRefs.
 *  ReferenceGrant is a form of runtime verification allowing users to assert which cross-namespace object references are permitted. Implementations that support ReferenceGrant MUST NOT permit cross-namespace references which have no grant, and MUST respond to the removal of a grant by revoking the access that the grant allowed.
 */
export class ReferenceGrant extends Model {
    constructor(data) {
        super({
            apiVersion: ReferenceGrant.apiVersion,
            kind: ReferenceGrant.kind,
            ...data
        });
    }
}
ReferenceGrant.apiVersion = "gateway.networking.k8s.io/v1alpha2";
ReferenceGrant.kind = "ReferenceGrant";
ReferenceGrant.is = createTypeMetaGuard(ReferenceGrant);
setValidateFunc(ReferenceGrant, validate);
