import { Model, setValidateFunc, createTypeMetaGuard } from "@kubernetes-models/base";
import { validate } from "../../_schemas/GatewayNetworkingK8sIoV1alpha2TLSRoute.mjs";
/**
 * The TLSRoute resource is similar to TCPRoute, but can be configured to match against TLS-specific metadata. This allows more flexibility in matching streams for a given TLS listener.
 *  If you need to forward traffic to a single target for a TLS listener, you could choose to use a TCPRoute with a TLS listener.
 */
export class TLSRoute extends Model {
    constructor(data) {
        super({
            apiVersion: TLSRoute.apiVersion,
            kind: TLSRoute.kind,
            ...data
        });
    }
}
TLSRoute.apiVersion = "gateway.networking.k8s.io/v1alpha2";
TLSRoute.kind = "TLSRoute";
TLSRoute.is = createTypeMetaGuard(TLSRoute);
setValidateFunc(TLSRoute, validate);
